Task: SST Sentiment Analysis
=============================
Description: Dataset containing sentiment trees of movie reviews. We use the modified binary sentence analysis subtask given by the DecaNLP paper here, originally from Radford, et. al https://nlp.stanford.edu/sentiment/index.html https://github.com/openai/generating-reviews-discovering-sentiment/

Tags: #sst, #All, #decanlp

